@@ -341,6 +341,10 @@ void OCLToSPIRVBase::visitCallInst(CallInst &CI) {
     visitCallDot(&CI, MangledName, DemangledName);
     return;
   }
+  if (DemangledName.startswith(kOCLBuiltinName::ClockReadPrefix)) {
+    visitCallClockRead(&CI, MangledName, DemangledName);
+    return;
+  }
   if (DemangledName == kOCLBuiltinName::FMin ||
       DemangledName == kOCLBuiltinName::FMax ||
       DemangledName == kOCLBuiltinName::Min ||
@@ -1445,6 +1449,25 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
       &Attrs);
 }
 
+void OCLToSPIRVBase::visitCallClockRead(CallInst *CI, StringRef MangledName,
+                                        StringRef DemangledName) {
+  // The builtin returns i64 or <2 x i32>, but both variants are mapped to the
+  // same instruction; hence include the return type.
+  const std::string OpName = getSPIRVFuncName(OpReadClockKHR, CI->getType());
+
+  // Scope is part of the OpenCL builtin name.
+  const Scope ScopeArg = StringSwitch<Scope>(DemangledName)
+                             .EndsWith("device", ScopeDevice)
+                             .EndsWith("work_group", ScopeWorkgroup)
+                             .EndsWith("sub_group", ScopeSubgroup)
+                             .Default(ScopeMax);
+
+  mutateCallInstSPIRV(M, CI, [=](CallInst *, std::vector<Value *> &Args) {
+    Args.push_back(getInt32(M, ScopeArg));
+    return OpName;
+  });
+}
+
 void OCLToSPIRVBase::visitCallScalToVec(CallInst *CI, StringRef MangledName,
                                         StringRef DemangledName) {
   // Check if all arguments have the same type - it's simple case.
