@@ -2,7 +2,6 @@
 
 _SPIRV_OP_INTERNAL(Forward, internal::OpForward)
 _SPIRV_OP_INTERNAL(TypeTokenINTEL, internal::OpTypeTokenINTEL)
-_SPIRV_OP_INTERNAL(ArithmeticFenceINTEL, internal::OpArithmeticFenceINTEL)
 _SPIRV_OP_INTERNAL(ConvertFToBF16INTEL, internal::OpConvertFToBF16INTEL)
 _SPIRV_OP_INTERNAL(ConvertBF16ToFINTEL, internal::OpConvertBF16ToFINTEL)
 _SPIRV_OP_INTERNAL(TypeJointMatrixINTEL, internal::OpTypeJointMatrixINTEL)
@@ -35,18 +34,3 @@ _SPIRV_OP_INTERNAL(ConvertHandleToSamplerINTEL,
                    internal::ConvertHandleToSamplerINTEL)
 _SPIRV_OP_INTERNAL(ConvertHandleToSampledImageINTEL,
                    internal::ConvertHandleToSampledImageINTEL)
-_SPIRV_OP_INTERNAL(PredicatedLoadINTEL,
-                   internal::OpPredicatedLoadINTEL)
-_SPIRV_OP_INTERNAL(PredicatedStoreINTEL,
-                   internal::OpPredicatedStoreINTEL)
-_SPIRV_OP_INTERNAL(FSigmoidINTEL, internal::FSigmoidINTEL)
-_SPIRV_OP_INTERNAL(ClampConvertFToFINTEL,
-                   internal::OpClampConvertFToFINTEL)
-_SPIRV_OP_INTERNAL(StochasticRoundFToFINTEL,
-                   internal::OpStochasticRoundFToFINTEL)
-_SPIRV_OP_INTERNAL(ClampStochasticRoundFToFINTEL,
-                   internal::OpClampStochasticRoundFToFINTEL)
-_SPIRV_OP_INTERNAL(ClampConvertFToSINTEL,
-                   internal::OpClampConvertFToSINTEL)
-_SPIRV_OP_INTERNAL(ClampStochasticRoundFToSINTEL,
-                   internal::OpClampStochasticRoundFToSINTEL)
